import os

from .deployments.deployments import Deployments
from .models.models import Models


_API_KEY = os.getenv('X_MEDIAMAGIC_KEY')


class PingPong():
    """
    PingPong - is a vanity class, which simply
    combined the underlying libraries into one
    object with the api configured for each etc.
    """

    models: Models
    deployments: Deployments

    def __init__(self, api_key=_API_KEY):
        self.models = Models(api_key=api_key)
        self.deployments = Deployments(api_key=api_key)



from dataclasses import dataclass

@dataclass
class Job:
    id: str
    credits_used: str
    results: list[str]


@dataclass
class Deployment:
    id: str
    model_id: str
    job: Job


@dataclass
class CreateDeployment:
    model_id: str
    args: dict
    name: str

    def dict(self):
        return super().dict()


def dto(m: dict) -> Deployment:
    return Deployment(
        id=m.get('id'),
        model_id=m.get('model_id'),
        job=m.get('job'),
    )



from ..shared.client.client import Client
from .model import Deployment, dto, CreateDeployment

from dataclasses import asdict


class Deployments(Client):
    def __init__(self, api_key: str) -> None:
        super().__init__(api_key)


    def get_by_id(self, id: str) -> Deployment:
        """
        get_by_id - get a deployment by its ID
        """
        deployment = super().get("/api/v1/deployments/%s" % id)
        return dto(deployment)
    

    def create(self, deployment: CreateDeployment) -> Deployment:
        """
        create - create a new Deployment
        """
        try:
            deployment = super().post("/api/v1/deployments", asdict(deployment))
            print(deployment)
            # return dto(deployment)
        except Exception as e:
            raise Exception('error creating deployment %s' % e)


    def list(self, start: int, to: int) -> list[Deployment]:
        """
        list - list all of your deployments
        """
        deployments = super().get("/api/v1/deployments", start, to)

        result = []
        for d in deployments:
            result.append(dto(d))

        return result
